<?php
/*
	Copyright (c) PORTANEO.

	This file is part of POSH (Portaneo Open Source Homepage) http://sourceforge.net/projects/posh/.

	POSH is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version

	POSH is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Posh.  If not, see <http://www.gnu.org/licenses/>.
*/
/*
* é
 * Functions used to authentify a user
 * Can be overwrited
 */
 
 
 
/*
 * Lougout
 * Input : 
 *		-------------
 *	Output :
 *		-------------
 */
if (!function_exists('user_logout')):
function user_logout()
{
	close_session();
	//cancel autoconnexion
	setcookie('autoi');
	setcookie('autop');
	header("location:index.php");
	launch_hook('logout');
}
endif;

/*
 * Connects the user
 * Input :
 *	$id (int or string) : user login if logging in with a form, user id if logging in by cookie
 *	$pass (string) : password (form) or md5pass (coookie)
 *	$md5pass (bool) : true if the pass is in MD5 and $id is the user id
 * Output :
 *	$user (object) : user data
 *	$errormsg (string) : error string
 * Returns :
 *	True if loggued in correctly, false if not
 */
if (!function_exists('user_login')) :
function user_login($id,$pass,$md5pass=false,&$user,&$errormsg)
{
//	$user = object;
	$errormsg='';
	if ($md5pass)
	{
		$user = (object) null;
		return user_login_cookie($id,$pass,$user,$errormsg);
	}
	else
	{
		$user = (object) null;
		return user_login_form($id,$pass,$user,$errormsg);
	}
}
endif;

/*
 * Logging using cookie informations
 * Input :
 *	$id (int) : user id in the DB
 *	$md5pass (string) : password to verify
 * Output :
 *	$user (object) : informations about the user
 *	$errormsg (string) : error string if an error occcurs
 * Returns :
 *	True if the user is connected, false if not
 */
if (!function_exists('user_login_cookie')) :
function user_login_cookie($id,$md5pass,&$user,&$errormsg)
{
	global $DB,$authentif_getUser;
	launch_hook('user_login_cookie',$id,$md5pass);
	
	$DB->getResults($authentif_getUser,$DB->escape($id),$DB->quote($md5pass));
	if ($DB->nbResults()>0)
	{
		$row=$DB->fetch(0);
		if ($row["typ"]=="N" OR $row["typ"]=="M")
		{
			$errormsg.=lg("userNotValidated");
		}
		else
		{
			$user->id=$id;
			$user->username=$row["username"];
			$user->type=$row["typ"];
			$user->lang=$row["lang"];
			$user->longname=$row["long_name"]==""?$row["username"]:$row["long_name"];
			$user->pass=$md5pass;
			$DB->freeResults();
			return true;
		}
	}
	$DB->freeResults();
	return false;
}
endif;

/*
 * User logging (with form)
 * Input :
 *	$username (string)
 *	$password (string) : pass without md5
 * Output :
 *	$user (object) : contains user data
 *	$errormsg (string) : error string if an error occurs
 * Returns :
 *	True if correctly logged in, false if not 
 */
if (!function_exists('user_login_form')):
function user_login_form($username,$password,&$user,&$errormsg)
{
	global $DB,$authentif_getUserByName;
	launch_hook('user_login_form',$username,$password);
	//Check the password
	$DB->getResults($authentif_getUserByName,$DB->quote($username));
	if ($DB->nbResults()<=0)
	{
		$errormsg.=lg("incorrectLogin");
	}
	else
	{
		$row=$DB->fetch(0);
		if ($row["typ"]=="N" OR $row["typ"]=="M")
		{
			$errormsg.=lg("userNotValidated");
		}
		else if ($row["password"]<>md5($password))
		{
			$errormsg.=lg("incorrectLogin");
		}
		else
		{
			$user->id=$row["id"];
			$user->username=$username;
			$user->type=$row["typ"];
			$user->lang=$row["lang"];
			$user->longname=$row["long_name"]==""?$username:$row["long_name"];
			$user->pass = md5($password);
			$DB->freeResults();
			return true;
		}
	}
	$DB->freeResults();
	return false;
}
endif;
 

/*
 * Set the user cookie
 * Input :
 *	$user (object) : user data
 */
if (!function_exists('user_setcookie')) :
function user_setcookie($user)
{
	setcookie('autoi',$user->id,time()+31536000);
	setcookie('autop',$user->pass,time()+31536000);
}
endif;
 

?>